pub fn parse(source: &str) -> Result<CSharpRoot, OakError>Expand description
Parses C# source code into a CSharpRoot AST.
This is a convenience function that initializes the language, builder, and parser to process the source text.
Errors
Returns an oak_core::OakError if parsing fails.